==> haskell-yesod-persistent-1.6.0.2-96-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-persistent
version: 1.6.0.2
id: yesod-persistent-1.6.0.2-7jjyAZUM0DoVBadWB4LEc
key: yesod-persistent-1.6.0.2-7jjyAZUM0DoVBadWB4LEc
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>
category: Web, Yesod, Database
abi: 3b77c0b116c5e7f91135ee8a3e6f493f
exposed: True
exposed-modules:
    Yesod.Persist Yesod.Persist.Core
import-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-persistent-1.6.0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-persistent-1.6.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/yesod-persistent-1.6.0.2
hs-libraries: HSyesod-persistent-1.6.0.2-7jjyAZUM0DoVBadWB4LEc
depends:
    base-4.12.0.0 blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    conduit-1.3.1.1-E4rBVTg9hCWE6hpGqSUOjw
    persistent-2.10.1-1HVa64tOJIBEg8YZgocABU
    persistent-template-2.7.2-IIZTLmJ3dTXD33YMFE7g4O
    resource-pool-0.2.3.2-gJbLOXkUsfHOTyD1xpnwB
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0 transformers-0.5.6.2
    yesod-core-1.6.16.1-AaxdseMqDuFCYFFMnxXOh2
haddock-interfaces: /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock
haddock-html: /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-persistent-1.6.0.2-100-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-persistent
version: 1.6.0.2
id: yesod-persistent-1.6.0.2-KrxLUB63mdp5hIYQKPMkRX
key: yesod-persistent-1.6.0.2-KrxLUB63mdp5hIYQKPMkRX
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>
category: Web, Yesod, Database
abi: ab8520bb7f0eb6eed2e8e54faff8abc7
exposed: True
exposed-modules:
    Yesod.Persist Yesod.Persist.Core
import-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-persistent-1.6.0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-persistent-1.6.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/yesod-persistent-1.6.0.2
hs-libraries: HSyesod-persistent-1.6.0.2-KrxLUB63mdp5hIYQKPMkRX
depends:
    base-4.12.0.0 blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    conduit-1.3.1.1-F2avdKCTYaGL08mnA41Iqz
    persistent-2.10.1-IHGrZmBRrXDFb9jEveSxwm
    persistent-template-2.7.2-EOLRqYvh8jM94b3BlT2lMW
    resource-pool-0.2.3.2-gJbLOXkUsfHOTyD1xpnwB
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0 transformers-0.5.6.2
    yesod-core-1.6.16.1-2spCYIU2YZcBrzhZudsNgD
haddock-interfaces: /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock
haddock-html: /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
